==> apache-iceberg-1.5.2.tar.gz: apache-iceberg-1.5.2/api/src/test/java/org/apache/iceberg/Parameter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import org.junit.runners.Parameterized;

/**
 * The annotation is used to replace {@link Parameterized.Parameter} for Junit 5 parameterized
 * tests.
 *
 * <p>This implementation has been taken from Flink repository. The only difference is the "index"
 * field, renamed to be more intuitive
 *
 * @see <a
 *     href="https://github.com/apache/flink/blob/master/flink-test-utils-parent/flink-test-utils-junit/src/main/java/org/apache/flink/testutils/junit/extensions/parameterized/Parameter.java">
 *     Parameters</a>
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
public @interface Parameter {
  /**
   * Position for the parameter in each parameters Collection item. Assuming that parameterized test
   * has only one Parameter this index is set to 0 by default
   */
  int index() default 0;
}

==> apache-iceberg-1.9.2.tar.gz: apache-iceberg-1.9.2/api/src/test/java/org/apache/iceberg/Parameter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * The annotation is used to replace {@link org.junit.runners.Parameterized.Parameter} for Junit 5
 * parameterized tests.
 *
 * <p>This implementation has been taken from Flink repository. The only difference is the "index"
 * field, renamed to be more intuitive
 *
 * @see <a
 *     href="https://github.com/apache/flink/blob/master/flink-test-utils-parent/flink-test-utils-junit/src/main/java/org/apache/flink/testutils/junit/extensions/parameterized/Parameter.java">
 *     Parameters</a>
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
public @interface Parameter {
  /**
   * Position for the parameter in each parameters Collection item. Assuming that parameterized test
   * has only one Parameter this index is set to 0 by default
   */
  int index() default 0;
}
